==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property appImageConfigName The name of the App Image Config.
 * @property imageName The name of the Custom Image.
 * @property imageVersionNumber The version number of the Custom Image.
 */
public data class DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs(
    public val appImageConfigName: Output<String>,
    public val imageName: Output<String>,
    public val imageVersionNumber: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs> {
    override fun toJava():
        com.pulumi.aws.sagemaker.inputs.DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs =
        com.pulumi.aws.sagemaker.inputs.DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs.builder()
            .appImageConfigName(appImageConfigName.applyValue({ args0 -> args0 }))
            .imageName(imageName.applyValue({ args0 -> args0 }))
            .imageVersionNumber(imageVersionNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs].
 */
@PulumiTagMarker
public class DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgsBuilder internal
constructor() {
    private var appImageConfigName: Output<String>? = null

    private var imageName: Output<String>? = null

    private var imageVersionNumber: Output<Int>? = null

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("srqhhirypnbcfvhf")
    public suspend fun appImageConfigName(`value`: Output<String>) {
        this.appImageConfigName = value
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("tdjjiqbuwjmqesif")
    public suspend fun imageName(`value`: Output<String>) {
        this.imageName = value
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("kdliuoacgdygbdrr")
    public suspend fun imageVersionNumber(`value`: Output<Int>) {
        this.imageVersionNumber = value
    }

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("fqbvweryxbtxkwxk")
    public suspend fun appImageConfigName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appImageConfigName = mapped
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("twlyfqrtcfrgpbnu")
    public suspend fun imageName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.imageName = mapped
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("ydojmibkdumugdlu")
    public suspend fun imageVersionNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageVersionNumber = mapped
    }

    internal fun build(): DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs =
        DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs(
            appImageConfigName = appImageConfigName ?: throw PulumiNullFieldException("appImageConfigName"),
            imageName = imageName ?: throw PulumiNullFieldException("imageName"),
            imageVersionNumber = imageVersionNumber,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property appImageConfigName The name of the App Image Config.
 * @property imageName The name of the Custom Image.
 * @property imageVersionNumber The version number of the Custom Image.
 */
public data class DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs(
    public val appImageConfigName: Output<String>,
    public val imageName: Output<String>,
    public val imageVersionNumber: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs =
        com.pulumi.aws.sagemaker.inputs.DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs.builder()
            .appImageConfigName(appImageConfigName.applyValue({ args0 -> args0 }))
            .imageName(imageName.applyValue({ args0 -> args0 }))
            .imageVersionNumber(imageVersionNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs].
 */
@PulumiTagMarker
public class DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgsBuilder internal constructor() {
    private var appImageConfigName: Output<String>? = null

    private var imageName: Output<String>? = null

    private var imageVersionNumber: Output<Int>? = null

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("ivdffilvbutrxoja")
    public suspend fun appImageConfigName(`value`: Output<String>) {
        this.appImageConfigName = value
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("qwsbmqbubxolutwm")
    public suspend fun imageName(`value`: Output<String>) {
        this.imageName = value
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("bdqusmfqqdbnbcpu")
    public suspend fun imageVersionNumber(`value`: Output<Int>) {
        this.imageVersionNumber = value
    }

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("ueaccfnamiyyqmvl")
    public suspend fun appImageConfigName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appImageConfigName = mapped
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("kdlvmqjxtwaeyaja")
    public suspend fun imageName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.imageName = mapped
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("fkrbjsodrrehytoq")
    public suspend fun imageVersionNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageVersionNumber = mapped
    }

    internal fun build(): DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs =
        DomainDefaultUserSettingsRSessionAppSettingsCustomImageArgs(
            appImageConfigName = appImageConfigName ?: throw PulumiNullFieldException("appImageConfigName"),
            imageName = imageName ?: throw PulumiNullFieldException("imageName"),
            imageVersionNumber = imageVersionNumber,
        )
}
